@@ -31,7 +31,7 @@ summary(s3, stats = "cover")
 s4 <- simsum(data = tt, estvarname = "diff", true = -1, se = "se", df = "df", methodvar = "method", by = "dgm")
 
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
-all.equal(get_data(s1), get_data(s4))
+all.equal(tidy(s1), tidy(s4))
 
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
 tt$true <- -1
@@ -41,6 +41,23 @@ summary(s5, stats = "cover")
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
 summary(s2, stats = "cover")
 
+## ---------------------------------------------------------------------------------------------------------------------------------------------------
+data("MIsim", package = "rsimsum")
+data("MIsim2", package = "rsimsum")
+head(MIsim)
+head(MIsim2)
+
+## ---------------------------------------------------------------------------------------------------------------------------------------------------
+s6 <- simsum(data = MIsim, estvarname = "b", true = 0.50, se = "se", methodvar = "method")
+s7 <- simsum(data = MIsim2, estvarname = "b", true = 0.50, se = "se", methodvar = c("m1", "m2"))
+
+## ---------------------------------------------------------------------------------------------------------------------------------------------------
+print(s6)
+print(s7)
+
+## ---------------------------------------------------------------------------------------------------------------------------------------------------
+all.equal(tidy(s6)$est, tidy(s7)$est)
+
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
 data("frailty", package = "rsimsum")
 ms1 <- multisimsum(
@@ -65,7 +82,7 @@ ms2 <- multisimsum(
 summary(ms2, stats = "bias")
 
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
-identical(get_data(ms1), get_data(ms2))
+identical(tidy(ms1), tidy(ms2))
 
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
 frailty$lower <- frailty$b - qt(1 - 0.05 / 2, df = 10) * frailty$se
